# kiwi v0.0.3
------------------------
Written by Ori Yonay
------------------------

To install:
```
pip3 install kiwiml
```

Current Features:
* autodiff: A simple automatic numpy-compatible multidimensional differentiator
* Accuracy score function for calculating model accuracy
* Machine Learning Models:
  * Linear Regression
  * Logistic Regression
  * Single Dimensional Analysis
  * Perceptron
  * KNN
* PCA Decomposition
* Error Functions:
  * Mean-Squared Error
  * Cross-Entropy Loss

TODO:
* Error Functions: add mean absolute deviation
* Machine Learning Models:
  * Naive Bayes
  * SVM
  * Decision Tree
  * Random Forest
  * K-Means Clustering
  * Neural Network Library
     * Fully-Connected layer
     * Convolutional Layer
     * Residual Layer
     * ...
* Dataset Importer
* Autolearn
